clear;%clc;
format long;

%CASE DEFINING PARAMETERS
MinBulk=8000; %Tons pr week.
MinDeck=4800; %M^2 pr week.
MinPax=280; %Persons pr week.
SpreadDep=6; %Hours.
BLR=480; %Bulk loading rate base.
DLR=400; %Deck loading rate base.
Duration=2400; %Hours.
UB=20; %Upper boundary for the number of vessels of one type.
T_r=[0.95 0.95 0.95]; %Threshold reliability. (the probability that the actual performance of the solution is better than the returned value.)
T_p=[0.9 0.9 0.9]; %Threshold performance. (the limit for what transportation coverage that is acceptable.)
C_r=0.95; %Cost reliability. (the probability that the actual cost will be lower than the returned value.)

%ALGORITHM DEFINING PARAMETERS
FB=1; FD=1; FP=1; %The initial values of the adjustment factors. 
R=1000; %The number of "rounds" in the Nested Partitions algorithm.
NoFromNP=100; %The maximum number of unique solutions transferred from NP to GA.
NoPar=NoFromNP; %The population size in the GA.
Generations=200; %The number of generations in the GA.
NoSim=6; %The maximum number of unique solutions being simulated at a time.
f=1; %The counter for the adjustment factor.
%t=0;

%WRITING TO THE DATASET-FILE
xlswrite('DataSet1.xlsx',[MinBulk MinDeck MinPax]','Input','B10:B12');
xlswrite('DataSet1.xlsx',SpreadDep,'Input','B13');
xlswrite('DataSet1.xlsx',[BLR,DLR]','Input','B30:B31');

%READING FROM THE DATASET-FILE
A1=xlsread('DataSet1.xlsx','Input','B4:B40');
A2=xlsread('DataSet1.xlsx','Vessels','D2:Q11');
A3=xlsread('DataSet1.xlsx','Rigs','B2:C8');

%SETTING THE BOUNDARIES FOR THE DECISION VARIABLES
AL=length(A2(:,1));
for i=1:AL
    ARS(i,:)=[0,UB,1];
end

circ=40075/1.852; %Circumference of the earth in nautical miles

%ROUND TRIP DISTANCE
for i=0:length(A3(:,1))
    if i<1
        arclen(i+1) = distance('rh',[A1(15),A1(16)],[A3(i+1,1),A3(i+1,2)])*circ/360;        
    elseif i>0 && i<length(A3(:,1))
        arclen(i+1) = distance('rh',[A3(i,1),A3(i,2)],[A3(i+1,1),A3(i+1,2)])*circ/360;
    else
        arclen(i+1) = distance('rh',[A3(i,1),A3(i,2)],[A1(15),A1(16)])*circ/360;
    end
end
RndDist=sum(arclen);

%AVERAGE DISTANCE FROM BASE TO PLATFORMS
for i=1:length(A3(:,1))
    arclen2(i) = distance('rh',[A1(15),A1(16)],[A3(i,1),A3(i,2)])*circ/360;        
end
AvgDist=sum(arclen2)/length(A3(:,1));


